sqlobject.tests.test_pickle module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_pickle module

class `sqlobject.tests.test_pickle.` `SOTestPickle`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `answer`
  `j` = so_test_pickle
  `q` = so_test_pickle
  property `question`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_pickle.SOTestPickle`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_pickle'

`sqlobject.tests.test_pickle.` `test_pickleCol`()